@@ -3,7 +3,6 @@
 @todo Add params for different state machines update times
 @todo Get a callback for missed calls to force an update of the voicemail state machine
 @todo Get a callback on an incoming call and if its from GV, auto-pickup
-@todo Decide if we should do what the spec suggests and hold onto a singleton contactlist
 """
 
 
@@ -102,10 +101,8 @@ class TheOneRingConnection(
 
 		if conic is not None:
 			self.__connection = conic.Connection()
-			self.__connectionEventId = None
 		else:
 			self.__connection = None
-			self.__connectionEventId = None
 		self.__cachePath = os.sep.join((constants._data_path_, "cache", self.username))
 		try:
 			os.makedirs(self.__cachePath)
@@ -182,6 +179,13 @@ class TheOneRingConnection(
 				)
 				self.__callbackNumberParameter = util_misc.normalize_number(callback)
 			self.session.backend.set_callback_number(self.__callbackNumberParameter)
+
+			subscribeHandle = self.get_handle_by_name(telepathy.HANDLE_TYPE_LIST, "subscribe")
+			subscribeProps = self._generate_props(telepathy.CHANNEL_TYPE_CONTACT_LIST, subscribeHandle, False)
+			self.__channelManager.channel_for_props(subscribeProps, signal=True)
+			publishHandle = self.get_handle_by_name(telepathy.HANDLE_TYPE_LIST, "publish")
+			publishProps = self._generate_props(telepathy.CHANNEL_TYPE_CONTACT_LIST, publishHandle, False)
+			self.__channelManager.channel_for_props(publishProps, signal=True)
 		except gvoice.backend.NetworkError, e:
 			_moduleLogger.exception("Connection Failed")
 			self.StatusChanged(
@@ -238,7 +242,7 @@ class TheOneRingConnection(
 
 		chan = self.__channelManager.channel_for_props(props, signal=True)
 		path = chan._object_path
-		_moduleLogger.info("RequestChannel Object Path: %s" % path)
+		_moduleLogger.info("RequestChannel Object Path (%s): %s" % (type.rsplit(".", 1)[-1], path))
 		return path
 
 	def _generate_props(self, channelType, handle, suppressHandler, initiatorHandle=None):
@@ -270,10 +274,6 @@ class TheOneRingConnection(
 		self.session.save(self.__cachePath)
 		self.session.logout()
 		self.session.close()
-		self.__session = None
-		if self.__connection is not None:
-			self.__connection.disconnect(self.__connectionEventId)
-			self.__connectionEventId = None
 
 		self.manager.disconnected(self)
 		_moduleLogger.info("Disconnected")
@@ -285,6 +285,20 @@ class TheOneRingConnection(
 			h = self.get_handle_by_name(telepathy.HANDLE_TYPE_CONTACT, phoneNumber)
 			# Just let the TextChannel decide whether it should be reported to the user or not
 			props = self._generate_props(telepathy.CHANNEL_TYPE_TEXT, h, False)
+			if self.__channelManager.channel_exists(props):
+				continue
+
+			# Maemo 4.1's RTComm opens a window for a chat regardless if a
+			# message is received or not, so we need to do some filtering here
+			mergedConv = conv.get_conversation(phoneNumber)
+			unreadConvs = [
+				conversation
+				for conversation in mergedConv.conversations
+				if not conversation.isRead and not conversation.isArchived
+			]
+			if not unreadConvs:
+				continue
+
 			chan = self.__channelManager.channel_for_props(props, signal=True)
 
 	@gtk_toolbox.log_exception(_moduleLogger)
@@ -294,6 +308,9 @@ class TheOneRingConnection(
 
 		@todo Make this delayed to handle background switching of networks.  First I need to verify I receive connected
 		"""
+		if not self.session.is_logged_in():
+			_moduleLogger.info("Received connection change event when not logged in")
+			return
 		status = event.get_status()
 		error = event.get_error()
 		iap_id = event.get_iap_id()
